@@ -20,10 +20,10 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <garcon/garcon-environment.h>
+#include "garcon-environment.h"
 
 
 /**
